@@ -1,34 +1,27 @@
+from qtstrap import OPTIONS
 from .qt import *
 import signal
 from pathlib import Path
 
-try:
-    import app_info
-    app_info_available = True
-except ModuleNotFoundError:
-    app_info_available = False
-
 
 class BaseApplication(QApplication):
-    organization_name = None
-    organization_domain = None
-    application_name = None
-    application_version = None
-    
     def __init__(self, *args, register_ctrlc_handler=True, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-        if app_info_available:
-            self.init_app_info(app_info)
+        if OPTIONS.app_info:
+            self.init_app_info(OPTIONS.app_info)
+            self.init_app_icon(OPTIONS.app_info.AppIconName)
 
         if register_ctrlc_handler:
             self.init_ctrlc_handler()
 
     def ctrlc_handler(self, sig=None, frame=None):
+        #! I don't think this does what I was hoping
         # give all the app's children a chance to close
-        for child in self.children():
-            if hasattr(child, 'close'):
-                child.close()
+        # for child in self.children():
+        #     print(child)
+        #     if hasattr(child, 'close'):
+        #         child.close()
 
         # TODO: should we somehow wait for our children to close?
 
@@ -50,14 +43,14 @@ class BaseApplication(QApplication):
     
     def init_app_info(self, info):
         if info.AppPublisher:
-            self.organization_name = info.AppPublisher
             self.setOrganizationName(info.AppPublisher)
         if info.AppPublisher:
-            self.organization_domain = info.AppPublisher
             self.setOrganizationDomain(info.AppPublisher)
         if info.AppName:
-            self.application_name = info.AppName
             self.setApplicationName(info.AppName)
         if info.AppVersion:
-            self.application_version = info.AppVersion
-            self.setApplicationVersion(info.AppVersion)
\ No newline at end of file
+            self.setApplicationVersion(info.AppVersion)
+
+    def init_app_icon(self, icon_path):
+        if icon_path and Path(icon_path).exists():
+                self.setWindowIcon(QIcon(icon_path))
\ No newline at end of file
